@@ -95,6 +95,29 @@ typedef struct OrderHintInfo {
 
 } OrderHintInfo;
 
+typedef struct EbTimingInfo {
+    /*!< Timing info present flag */
+    bool timing_info_present;
+
+    /*!< Number of time units of a clock operating at the frequency time_scale
+     * Hz that corresponds to one increment of a clock tick counter*/
+    uint32_t num_units_in_display_tick;
+
+    /*!< Number of time units that pass in one second*/
+    uint32_t time_scale;
+
+    /*!< Equal to 1 indicates that pictures should be displayed according to
+     * their output order with the number of ticks between two consecutive
+     * pictures specified by num_ticks_per_picture.*/
+    uint8_t equal_picture_interval;
+
+    /*!< Specifies the number of clock ticks corresponding to output time
+     * between two consecutive pictures in the output order.
+     * Range - [0 to (1 << 32) - 2]*/
+    uint32_t num_ticks_per_picture;
+
+} EbTimingInfo;
+
 typedef struct SeqHeader {
     /*!< Specifies the features that can be used in the coded video sequence */
     EbAv1SeqProfile seq_profile;
@@ -183,9 +206,6 @@ typedef struct SeqHeader {
     /*!< Specifies whether the intra edge filtering process should be enabled */
     uint8_t enable_intra_edge_filter;
 
-    /*!< Specifies whether the picture based rate estimation should be enabled */
-    uint8_t pic_based_rate_est;
-
     /*!< Specifies whether the intra angle delta filtering process should be enabled */
     uint8_t enable_intra_angle_delta_filter;
 
@@ -544,7 +564,7 @@ typedef struct FrameHeader {
     uint8_t lossless_array[MAX_SEGMENTS];
 
     /*!< Loop Filter Parameters */
-    struct LoopFilter loop_filter_params;
+    LoopFilter loop_filter_params;
 
     /*!< Constrained Directional Enhancement Filter */
     CdefParams cdef_params;
