@@ -12,6 +12,7 @@
 //
 #ifndef EbDefinitions_h
 #define EbDefinitions_h
+
 #include <stdint.h>
 #include <stdlib.h>
 #include <string.h>
@@ -20,6 +21,7 @@
 #include "EbSvtAv1.h"
 #include "EbSvtAv1Enc.h"
 #include <stdbool.h>
+
 #ifdef _WIN32
 #define inline __inline
 #elif __GNUC__
@@ -28,6 +30,20 @@
 #define inline
 #endif
 
+#define INLINE inline
+
+#ifdef _WIN32
+#define NOINLINE __declspec(noinline)
+#else
+#define NOINLINE __attribute__((noinline))
+#endif
+
+#if EXCLUDE_HASH
+#define EB_LINE_NUM 0
+#else
+#define EB_LINE_NUM __LINE__
+#endif
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -41,7 +57,7 @@ extern "C" {
 #define MAX_TPL_GROUP_SIZE 512 //enough to cover 6L gop
 
 #define MAX_TPL_EXT_GROUP_SIZE MAX_TPL_GROUP_SIZE
-#define OUT_Q_ADVANCE(h) ((h == REFERENCE_QUEUE_MAX_DEPTH - 1) ? 0 : h + 1)
+#define OUT_Q_ADVANCE(h, size) (((h) == (size) - 1) ? 0 : (h) + 1)
 #define MIN_LAD_MG 1
 #define RC_DEFAULT_LAD_MG 2 // default look ahead value for rate control
 void svt_aom_assert_err(uint32_t condition, char *err_msg);
@@ -68,9 +84,6 @@ void svt_aom_assert_err(uint32_t condition, char *err_msg);
 #define VQ_NOISE_LVL_TH 15000
 #define VQ_STABILITY_ME_VAR_TH 750
 #define VQ_PIC_AVG_VARIANCE_TH 1000
-
-#define MDS0_REDUCE_ANGULAR_INTRA_TH 25
-
 #define NUM_MV_COMPONENTS 2
 #define NUM_MV_HIST 2
 #define MAX_MV_HIST_SIZE 2 * REF_LIST_MAX_DEPTH *NUM_MV_COMPONENTS *NUM_MV_HIST
@@ -87,14 +100,8 @@ typedef struct SharpnessCtrls {
     uint8_t restoration;
     uint8_t rdoq;
 } SharpnessCtrls;
-
-typedef struct StabilityCtrls {
-    uint8_t depth_refinement;
-} StabilityCtrls;
-
 typedef struct VqCtrls {
     SharpnessCtrls sharpness_ctrls;
-    StabilityCtrls stability_ctrls;
 } VqCtrls;
 typedef struct MrpCtrls {
     /*
@@ -134,6 +141,16 @@ typedef struct MrpCtrls {
     //2:use with TPL constraint                 faster
     //3:use with no constraint                  fastest
     uint8_t use_best_references;
+    // When LD rtc is used, reduce the number of ref buffers based on the number of references used
+    // and the known rps structure. Signal is set automatically based on refs used.
+    // 0: off, use at least DPB ref buffers.
+    // 1: on; when each ref list uses <=2 refs, reduce the number of ref frame buffers because only
+    // base and layer1 pics are added to the dpb.
+    // 2: on; when each ref list uses <=1 refs, further reduce the number of ref frame buffers because only
+    // one base and one layer1 pic are added to the dpb at a time.
+    uint8_t ld_reduce_ref_buffs;
+    // When flat rtc structure is used, this is the number of refs to use (from previous consecutive frames)
+    uint8_t flat_max_refs;
 
 } MrpCtrls;
 typedef struct TfControls {
@@ -229,12 +246,15 @@ typedef enum SqWeightOffsets {
     AGGRESSIVE_OFFSET_0   = -5,
     AGGRESSIVE_OFFSET_1   = -10
 } SqWeightOffsets;
-#define COEFF_LVL_TH_0 (5833 / 48)
-#define COEFF_LVL_TH_1 (16666 / 48)
+
+#define COEFF_LVL_TH_0 (5833 / 96)
+#define COEFF_LVL_TH_1 (5833 / 48)
+#define COEFF_LVL_TH_2 (16666 / 48)
 typedef enum InputCoeffLvl {
-    LOW_LVL     = 0,
-    NORMAL_LVL  = 1,
-    HIGH_LVL    = 2,
+    VLOW_LVL    = 0,
+    LOW_LVL     = 1,
+    NORMAL_LVL  = 2,
+    HIGH_LVL    = 3,
     INVALID_LVL = ~0,
 } InputCoeffLvl;
 typedef struct Buf2D {
@@ -317,8 +337,6 @@ enum {
 #define MAX_TXB_COUNT_UV 4 // Maximum number of transform blocks per depth for chroma planes
 #define MAX_LAD 120 // max lookahead-distance 2x60fps
 #define ROUND_UV(x) (((x) >> 3) << 3)
-#define AV1_PROB_COST_SHIFT 9
-#define AOMINNERBORDERINPIXELS 160
 #define SWITCHABLE_FILTER_CONTEXTS ((SWITCHABLE_FILTERS + 1) * 4)
 #define MAX_MB_PLANE 3
 #define CFL_MAX_BlockSize (BLOCK_32X32)
@@ -332,9 +350,6 @@ enum {
 #define CONFIG_BUFFER_MODEL 1
 #define CONFIG_COEFFICIENT_RANGE_CHECKING 0
 #define CONFIG_ENTROPY_STATS 0
-#define CONFIG_FP_MB_STATS 0
-#define CONFIG_INTERNAL_STATS 0
-#define CONFIG_RD_DEBUG 0
 
 // Max superblock size
 #define MAX_SB_SIZE_LOG2 7
@@ -452,14 +467,6 @@ typedef int16_t InterpKernel[SUBPEL_TAPS];
 /***************************************************/
 /****************** Helper Macros ******************/
 /***************************************************/
-#ifdef ARCH_X86_64
-extern void RunEmms();
-#define aom_clear_system_state() RunEmms()
-#else
-#define aom_clear_system_state() \
-    {}
-#endif
-
 /* Shift down with rounding for use when n >= 0, value >= 0 */
 #define ROUND_POWER_OF_TWO(value, n) (((value) + (((1 << (n)) >> 1))) >> (n))
 
@@ -474,7 +481,7 @@ extern void RunEmms();
 #define ROUND_POWER_OF_TWO_SIGNED_64(value, n) \
     (((value) < 0) ? -ROUND_POWER_OF_TWO_64(-(value), (n)) : ROUND_POWER_OF_TWO_64((value), (n)))
 
-#define IS_POWER_OF_TWO(x) (((x) & ((x)-1)) == 0)
+#define IS_POWER_OF_TWO(x) (((x) & ((x) - 1)) == 0)
 
 #ifdef __cplusplus
 #define EB_EXTERN extern "C"
@@ -482,7 +489,6 @@ extern void RunEmms();
 #define EB_EXTERN
 #endif // __cplusplus
 
-#define INLINE __inline
 #define RESTRICT
 #ifdef _WIN32
 #define FOPEN(f, s, m) fopen_s(&f, s, m)
@@ -708,12 +714,6 @@ static const uint32_t MD_STAGE_NICS_SCAL_NUM[NICS_SCALING_LEVELS][MD_STAGE_TOTAL
     {0, 2, 0, 0}, // LEVEL 14
     {0, 0, 0, 0} // LEVEL 15
 };
-// NICS
-#define MAX_FRAME_TYPE 3 // Max number of frame type allowed for nics
-#define ALL_S0 -1 // Allow all candidates from stage0
-#define MAX_REF_TYPE_CAND 30
-#define PRUNE_REC_TH 5
-#define PRUNE_REF_ME_TH 2
 typedef enum {
     EIGHTTAP_REGULAR,
     EIGHTTAP_SMOOTH,
@@ -757,6 +757,12 @@ typedef enum IfsLevel {
     IFS_MDS2, // IFS @ md_stage_2()
     IFS_MDS3, // IFS @ md_stage_3()
 } IfsLevel;
+typedef enum SpatialSseLevel {
+    SSSE_MDS1, // Spatial SSE @ md_stage_1() and beyond
+    SSSE_MDS2, // Spatial SSE @ md_stage_2() and beyond
+    SSSE_MDS3, // Spatial SSE @ md_stage_3() and beyond
+    SSSE_OFF // Spatial SSE OFF
+} SpatialSseLevel;
 typedef enum DistortionType { SAD, VAR, SSD, DIST_TYPES } DistortionType;
 // Profile 0.  8-bit and 10-bit 4:2:0 and 4:0:0 only.
 // Profile 1.  8-bit and 10-bit 4:4:4
@@ -1168,7 +1174,6 @@ typedef enum ATTRIBUTE_PACKED {
     INTRA_MODES             = PAETH_PRED + 1, // PAETH_PRED has to be the last intra mode.
     INTRA_INVALID           = MB_MODE_COUNT, // For uv_mode in inter blocks
 } PredictionMode;
-
 #define MAX_UPSAMPLE_SZ 16
 
 typedef enum ATTRIBUTE_PACKED {
@@ -1420,8 +1425,6 @@ typedef enum ATTRIBUTE_PACKED {
 #define PRIMARY_REF_BITS 3
 #define PRIMARY_REF_NONE 7
 
-#define NUM_PING_PONG_BUFFERS 2
-
 #define MAX_NUM_TEMPORAL_LAYERS 8
 #define MAX_NUM_SPATIAL_LAYERS 4
 /* clang-format off */
@@ -1431,10 +1434,15 @@ typedef enum ATTRIBUTE_PACKED {
 MAX_NUM_TEMPORAL_LAYERS * MAX_NUM_SPATIAL_LAYERS
 
 static INLINE int32_t is_valid_seq_level_idx(uint8_t seq_level_idx) {
-    return seq_level_idx < 24 || seq_level_idx == 31;
+    return seq_level_idx == 31 ||
+        (seq_level_idx < 24 &&
+        // The following levels are currently undefined.
+        seq_level_idx != 2 && seq_level_idx != 3 &&
+        seq_level_idx != 6 && seq_level_idx != 7 &&
+        seq_level_idx != 10 && seq_level_idx != 11 &&
+        seq_level_idx != 20 && seq_level_idx != 21 &&
+        seq_level_idx != 22 && seq_level_idx != 23);
 }
-#define TXCOEFF_TIMER 0
-#define TXCOEFF_COST_TIMER 0
 
 typedef enum
 {
@@ -1595,162 +1603,26 @@ static const struct
 /* clang-format on */
 
 // Width/height lookup tables in units of various block sizes
-static const uint8_t block_size_wide[BlockSizeS_ALL] = {4,  4,  8,  8,   8,   16, 16, 16, 32, 32, 32,
-                                                        64, 64, 64, 128, 128, 4,  16, 8,  32, 16, 64};
-
-static const uint8_t block_size_high[BlockSizeS_ALL] = {4,  8,  4,   8,  16,  8,  16, 32, 16, 32, 64,
-                                                        32, 64, 128, 64, 128, 16, 4,  32, 8,  64, 16};
+extern const uint8_t block_size_wide[BlockSizeS_ALL];
+extern const uint8_t block_size_high[BlockSizeS_ALL];
 
 // AOMMIN(3, AOMMIN(b_width_log2(bsize), b_height_log2(bsize)))
-static const uint8_t size_group_lookup[BlockSizeS_ALL] = {0, 0, 0, 1, 1, 1, 2, 2, 2, 3, 3,
-                                                          3, 3, 3, 3, 3, 0, 0, 1, 1, 2, 2};
+extern const uint8_t eb_size_group_lookup[BlockSizeS_ALL];
 
-static const uint8_t num_pels_log2_lookup[BlockSizeS_ALL] = {4,  5,  5,  6,  7,  7, 8, 9, 9, 10, 11,
-                                                             11, 12, 13, 13, 14, 6, 6, 8, 8, 10, 10};
-static const TxSize  max_txsize_lookup[BlockSizeS_ALL]    = {
-    //                   4X4
-    TX_4X4,
-    // 4X8,    8X4,      8X8
-    TX_4X4,
-    TX_4X4,
-    TX_8X8,
-    // 8X16,   16X8,     16X16
-    TX_8X8,
-    TX_8X8,
-    TX_16X16,
-    // 16X32,  32X16,    32X32
-    TX_16X16,
-    TX_16X16,
-    TX_32X32,
-    // 32X64,  64X32,
-    TX_32X32,
-    TX_32X32,
-    // 64X64
-    TX_64X64,
-    // 64x128, 128x64,   128x128
-    TX_64X64,
-    TX_64X64,
-    TX_64X64,
-    // 4x16,   16x4,     8x32
-    TX_4X4,
-    TX_4X4,
-    TX_8X8,
-    // 32x8,   16x64     64x16
-    TX_8X8,
-    TX_16X16,
-    TX_16X16};
+extern const uint8_t eb_num_pels_log2_lookup[BlockSizeS_ALL];
+extern const TxSize  eb_max_txsize_lookup[BlockSizeS_ALL];
 
-static const TxSize max_txsize_rect_lookup[BlockSizeS_ALL] = {
-    // 4X4
-    TX_4X4,
-    // 4X8,    8X4,      8X8
-    TX_4X8,
-    TX_8X4,
-    TX_8X8,
-    // 8X16,   16X8,     16X16
-    TX_8X16,
-    TX_16X8,
-    TX_16X16,
-    // 16X32,  32X16,    32X32
-    TX_16X32,
-    TX_32X16,
-    TX_32X32,
-    // 32X64,  64X32,
-    TX_32X64,
-    TX_64X32,
-    // 64X64
-    TX_64X64,
-    // 64x128, 128x64,   128x128
-    TX_64X64,
-    TX_64X64,
-    TX_64X64,
-    // 4x16,   16x4,
-    TX_4X16,
-    TX_16X4,
-    // 8x32,   32x8
-    TX_8X32,
-    TX_32X8,
-    // 16x64,  64x16
-    TX_16X64,
-    TX_64X16};
+extern const TxSize eb_max_txsize_rect_lookup[BlockSizeS_ALL];
 
 // Transform block width in unit
-static const int32_t tx_size_wide_unit[TX_SIZES_ALL] = {
-    1, 2, 4, 8, 16, 1, 2, 2, 4, 4, 8, 8, 16, 1, 4, 2, 8, 4, 16,
-};
+extern const int32_t eb_tx_size_wide_unit[TX_SIZES_ALL];
 // Transform block height in unit
-static const int32_t tx_size_high_unit[TX_SIZES_ALL] = {
-    1, 2, 4, 8, 16, 2, 1, 4, 2, 8, 4, 16, 8, 4, 1, 8, 2, 16, 4,
-};
+extern const int32_t eb_tx_size_high_unit[TX_SIZES_ALL];
 
-static const TxSize sub_tx_size_map[TX_SIZES_ALL] = {
-    TX_4X4, // TX_4X4
-    TX_4X4, // TX_8X8
-    TX_8X8, // TX_16X16
-    TX_16X16, // TX_32X32
-    TX_32X32, // TX_64X64
-    TX_4X4, // TX_4X8
-    TX_4X4, // TX_8X4
-    TX_8X8, // TX_8X16
-    TX_8X8, // TX_16X8
-    TX_16X16, // TX_16X32
-    TX_16X16, // TX_32X16
-    TX_32X32, // TX_32X64
-    TX_32X32, // TX_64X32
-    TX_4X8, // TX_4X16
-    TX_8X4, // TX_16X4
-    TX_8X16, // TX_8X32
-    TX_16X8, // TX_32X8
-    TX_16X32, // TX_16X64
-    TX_32X16, // TX_64X16
-};
-static const TxSize txsize_horz_map[TX_SIZES_ALL] = {
-    TX_4X4, // TX_4X4
-    TX_8X8, // TX_8X8
-    TX_16X16, // TX_16X16
-    TX_32X32, // TX_32X32
-    TX_64X64, // TX_64X64
-    TX_4X4, // TX_4X8
-    TX_8X8, // TX_8X4
-    TX_8X8, // TX_8X16
-    TX_16X16, // TX_16X8
-    TX_16X16, // TX_16X32
-    TX_32X32, // TX_32X16
-    TX_32X32, // TX_32X64
-    TX_64X64, // TX_64X32
-    TX_4X4, // TX_4X16
-    TX_16X16, // TX_16X4
-    TX_8X8, // TX_8X32
-    TX_32X32, // TX_32X8
-    TX_16X16, // TX_16X64
-    TX_64X64, // TX_64X16
-};
+extern const TxSize eb_sub_tx_size_map[TX_SIZES_ALL];
 
-static const TxSize txsize_vert_map[TX_SIZES_ALL] = {
-    TX_4X4, // TX_4X4
-    TX_8X8, // TX_8X8
-    TX_16X16, // TX_16X16
-    TX_32X32, // TX_32X32
-    TX_64X64, // TX_64X64
-    TX_8X8, // TX_4X8
-    TX_4X4, // TX_8X4
-    TX_16X16, // TX_8X16
-    TX_8X8, // TX_16X8
-    TX_32X32, // TX_16X32
-    TX_16X16, // TX_32X16
-    TX_64X64, // TX_32X64
-    TX_32X32, // TX_64X32
-    TX_16X16, // TX_4X16
-    TX_4X4, // TX_16X4
-    TX_32X32, // TX_8X32
-    TX_8X8, // TX_32X8
-    TX_64X64, // TX_16X64
-    TX_16X16, // TX_64X16
-};
-static const uint8_t mi_size_wide_log2[BlockSizeS_ALL] = {0, 0, 1, 1, 1, 2, 2, 2, 3, 3, 3,
-                                                          4, 4, 4, 5, 5, 0, 2, 1, 3, 2, 4};
-static const uint8_t mi_size_high_log2[BlockSizeS_ALL] = {0, 1, 0, 1, 2, 1, 2, 3, 2, 3, 4,
-                                                          3, 4, 5, 4, 5, 2, 0, 3, 1, 4, 2};
+extern const uint8_t mi_size_wide_log2[BlockSizeS_ALL];
+extern const uint8_t mi_size_high_log2[BlockSizeS_ALL];
 
 typedef struct SgrParamsType {
     int32_t r[2]; // radii
@@ -1771,23 +1643,9 @@ typedef int8_t MvReferenceFrame;
 
 // Number of transform types in each set type
 
-static const int32_t av1_num_ext_tx_set[EXT_TX_SET_TYPES] = {
-    1,
-    2,
-    5,
-    7,
-    12,
-    16,
-};
+extern const int32_t av1_num_ext_tx_set[EXT_TX_SET_TYPES];
 
-static const int32_t av1_ext_tx_used[EXT_TX_SET_TYPES][TX_TYPES] = {
-    {1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
-    {1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0},
-    {1, 1, 1, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0},
-    {1, 1, 1, 1, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0},
-    {1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0},
-    {1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1},
-};
+extern const int32_t av1_ext_tx_used[EXT_TX_SET_TYPES][TX_TYPES];
 
 static INLINE TxSetType get_ext_tx_set_type(TxSize tx_size, int32_t is_inter, int32_t use_reduced_set) {
     const TxSize tx_size_sqr_up = txsize_sqr_up_map[tx_size];
@@ -1810,31 +1668,16 @@ static INLINE int32_t get_ext_tx_types(TxSize tx_size, int32_t is_inter, int32_t
     return av1_num_ext_tx_set[set_type];
 }
 // Maps tx set types to the indices.
-static const int32_t ext_tx_set_index[2][EXT_TX_SET_TYPES] = {
-    {// Intra
-     0,
-     -1,
-     2,
-     1,
-     -1,
-     -1},
-    {// Inter
-     0,
-     3,
-     -1,
-     -1,
-     2,
-     1},
-};
+extern const int32_t ext_tx_set_index[2][EXT_TX_SET_TYPES];
 
 static INLINE int32_t get_ext_tx_set(TxSize tx_size, int32_t is_inter, int32_t use_reduced_set) {
     const TxSetType set_type = get_ext_tx_set_type(tx_size, is_inter, use_reduced_set);
     return ext_tx_set_index[is_inter][set_type];
 }
-static INLINE Bool is_intra_mode(PredictionMode mode) {
+static INLINE bool is_intra_mode(PredictionMode mode) {
     return mode < INTRA_MODE_END; // && mode >= INTRA_MODE_START; // mode is always greater than INTRA_MODE_START
 }
-static INLINE Bool is_inter_mode(PredictionMode mode) {
+static INLINE bool is_inter_mode(PredictionMode mode) {
     return mode >= SINGLE_INTER_MODE_START && mode < COMP_INTER_MODE_END;
 }
 static INLINE int32_t is_inter_compound_mode(PredictionMode mode) {
@@ -1878,16 +1721,12 @@ typedef enum FrameContextIndex {
 // Total number of QM sets stored
 #define QM_LEVEL_BITS 4
 #define NUM_QM_LEVELS (1 << QM_LEVEL_BITS)
-//**********************************************************************************************************************//
-// blockd.h
-#define NO_FILTER_FOR_IBC 1 // Disable in-loop filters for frame with intrabc
-//**********************************************************************************************************************//
 // av1_loopfilter.h
 #define MAX_LOOP_FILTER 63
 #define MAX_SHARPNESS 7
 #define SIMD_WIDTH 16
 
-struct LoopFilter {
+typedef struct LoopFilter {
     int32_t filter_level[2];
     int32_t filter_level_u;
     int32_t filter_level_v;
@@ -1904,15 +1743,11 @@ struct LoopFilter {
     // 0 = ZERO_MV, MV
     int8_t  mode_deltas[MAX_MODE_LF_DELTAS];
     int32_t combine_vert_horz_lf;
-};
+} LoopFilter;
 
 #define MAX_SEGMENTS 8
 #define MAX_MB_PLANE 3
 
-#define MAX_LOOP_FILTER 63
-#define MAX_SHARPNESS 7
-
-#define SIMD_WIDTH 16
 // Need to align this structure so when it is declared and
 // passed it can be loaded into vector registers.
 typedef struct LoopFilterThresh {
@@ -1935,7 +1770,7 @@ typedef struct LoopFilterInfoN {
 // Given the general homography:
 //      [x'     (a  b  c   [x
 //  z .  y'  =   d  e  f *  y
-//       1]      g  h  i)    1]
+//       1]      0  0  1)    1]
 //
 // Constants using the name ALPHA here are related to parameters
 // a, b, d, e. Constants using the name TRANS are related
@@ -1985,26 +1820,25 @@ typedef struct LoopFilterInfoN {
 #define GM_ALPHA_MIN -GM_ALPHA_MAX
 #define GM_ROW3HOMO_MIN -GM_ROW3HOMO_MAX
 /* clang-format off */
-typedef enum TransformationType
-{
+typedef enum TransformationType {
     IDENTITY = 0,      // identity transformation, 0-parameter
     TRANSLATION = 1,   // translational motion 2-parameter
     ROTZOOM = 2,       // simplified affine with rotation + zoom only, 4-parameter
     AFFINE = 3,        // affine, 6-parameter
     TRANS_TYPES,
 } TransformationType;
+#define MAX_PARAMDIM 6
 // The order of values in the wmmat matrix below is best described
-// by the homography:
+// by the affine transformation:
 //      [x'     (m2 m3 m0   [x
 //  z .  y'  =   m4 m5 m1 *  y
-//       1]      m6 m7 1)    1]
-typedef struct EbWarpedMotionParams
-{
+//       1]       0  0 1)    1]
+typedef struct WarpedMotionParams {
     TransformationType wmtype;
-    int32_t wmmat[8];
+    int32_t wmmat[MAX_PARAMDIM];
     int16_t alpha, beta, gamma, delta;
     int8_t invalid;
-} EbWarpedMotionParams;
+} WarpedMotionParams;
 
 /*! Scale factors and scaling function pointers  when reference and current frame dimensions are not equal */
 typedef struct ScaleFactors {
@@ -2018,10 +1852,9 @@ typedef struct ScaleFactors {
 } ScaleFactors;
 
 /* clang-format off */
-static const EbWarpedMotionParams default_warp_params = {
+static const WarpedMotionParams default_warp_params = {
     IDENTITY,
-{ 0, 0, (1 << WARPEDMODEL_PREC_BITS), 0, 0, (1 << WARPEDMODEL_PREC_BITS), 0,
-0 },
+{ 0, 0, (1 << WARPEDMODEL_PREC_BITS), 0, 0, (1 << WARPEDMODEL_PREC_BITS) },
 0, 0, 0, 0,
 0,
 };
@@ -2031,14 +1864,6 @@ static const EbWarpedMotionParams default_warp_params = {
 //**********************************************************************************************************************//
 //**********************************************************************************************************************//
 
-#ifdef _WIN32
-#define NOINLINE                __declspec ( noinline )
-#define FORCE_INLINE            __forceinline
-#else
-#define NOINLINE                __attribute__(( noinline ))
-#define FORCE_INLINE            __attribute__((always_inline))
-#endif
-
 // ***************************** Definitions *****************************
 
 #define MAX_BITS_PER_FRAME            8000000
@@ -2060,7 +1885,11 @@ static const EbWarpedMotionParams default_warp_params = {
 #define INPUT_SIZE_720p_TH                  0x16DA00     // 1.5 Million
 #define INPUT_SIZE_1080p_TH                 0x535200     // 5.46 Million
 #define INPUT_SIZE_4K_TH                    0x140A000    // 21 Million
-#define EB_OUTPUTSTREAMBUFFERSIZE_MACRO(ResolutionSize)                ((ResolutionSize) < (INPUT_SIZE_720p_TH) ? 0x1E8480 : 0x2DC6C0)
+#define INPUT_SIZE_8K_TH                    0X5028000    // 84 Million
+
+// There must absolutely be no reason to use more than 2x of original bytes, assuming 4:2:0
+#define BITSTREAM_BUFFER_SIZE(pixels)       ((pixels) * 3 / 2 * 2)
+
 /** Redefine ASSERT() to avoid warnings
 */
 #if defined _DEBUG || _DEBUG_
@@ -2123,24 +1952,39 @@ typedef enum MD_BIT_DEPTH_MODE
     EB_DUAL_BIT_MD  = 2     // Auto: 8bit & 10bit mode decision
 } MD_BIT_DEPTH_MODE;
 
+ /* Indicates what prediction structure to use
+  *
+  * SVT_AV1_PRED_UNUSED is not used, and not supported in the code. It is a placeholder after removing SVT_AV1_PRED_LOW_DELAY_P
+  * so that the values for --pred-struct don't need to change.
+  *
+  * TODO: At v4.0 remove PRED_UNUSED to have only LOW_DELAY and RANDOM_ACCESS. Need to update documentation for --pred-struct
+  */
+typedef enum PredStructure {
+    PRED_UNUSED = 0, // Do not use
+    LOW_DELAY = 1,
+    RANDOM_ACCESS = 2,
+    PRED_TOTAL_COUNT = 3,
+    PRED_INVALID = 0xFF
+} PredStructure;
+
+typedef enum Tune {
+    TUNE_VQ   = 0, // Visual Quality (video)
+    TUNE_PSNR = 1, // Average of (PSNR, SSIM, VMAF)
+    TUNE_SSIM = 2, // SSIM-optimized
+    TUNE_IQ   = 3, // Image Quality
+    TUNE_MS_SSIM = 4 // MS_SSIM and SSIMULACRA2 optimized
+
+} Tune;
+
 /*
  * The SliceType type is used to describe the slice prediction type.
  */
 typedef enum ATTRIBUTE_PACKED {
-    B_SLICE = 0,
-    P_SLICE = 1,
-    I_SLICE = 2,
-    IDR_SLICE = 3,
+    B_SLICE = 0, // Inter frame
+    I_SLICE = 1, // Intra only frame
     INVALID_SLICE = 0xFF
 } SliceType;
 
-/** The EbModeType type is used to describe the PU type.
-*/
-typedef uint8_t EbModeType;
-#define INTER_MODE 1
-#define INTRA_MODE 2
-
-#define INVALID_MODE 0xFFu
 #define SPEED_CONTROL_INIT_MOD ENC_M5;
 typedef enum ATTRIBUTE_PACKED {
     REF_LIST_0 = 0,
@@ -2198,29 +2042,6 @@ object_init_data_ptr is a EbPtr to a data structure used to initialize the objec
 typedef EbErrorType(*EbCreator)(
     EbPtr *object_dbl_ptr,
     EbPtr object_init_data_ptr);
-
-#define INVALID_MV            0x80008000 //0xFFFFFFFF    //ICOPY They changed this to 0x80008000
-/***************************************
-* Generic linked list data structure for passing data into/out from the library
-***************************************/
-typedef int32_t EbLinkedListType;
-
-typedef struct EbLinkedListNode
-{
-    void*                     app;                       // points to an application object this node is associated
-                                                            // with. this is an opaque pointer to the encoder lib, but
-                                                            // release_cb_fnc_ptr may need to access it.
-    EbLinkedListType       type;                      // type of data pointed by "data" member variable
-    uint32_t                    size;                      // size of (data)
-    Bool                   passthrough;               // whether this is passthrough data from application
-    void(*release_cb_fnc_ptr)(struct EbLinkedListNode*); // callback to be executed by encoder when picture reaches end of pipeline, or
-                                                        // when aborting. However, at end of pipeline encoder shall
-                                                        // NOT invoke this callback if passthrough is TRUE (but
-                                                        // still needs to do so when aborting)
-    void                     *data;                      // pointer to application's data
-    struct EbLinkedListNode  *next;                      // pointer to next node (null when last)
-} EbLinkedListNode;
-
 typedef enum DistCalcType
 {
     DIST_CALC_RESIDUAL = 0,    // SSE(Coefficients - ReconCoefficients)
@@ -2253,10 +2074,6 @@ typedef struct EbMemoryMapEntry
     EbPtr                    prev_entry;     // pointer to the prev entry
 } EbMemoryMapEntry;
 
-// Rate Control
-#define THRESHOLD1QPINCREASE     1
-#define THRESHOLD2QPINCREASE     2
-
 #define ALVALUE 64
 
 #define EB_CREATE_SEMAPHORE(pointer, initial_count, max_count) \
@@ -2289,27 +2106,10 @@ typedef struct EbMemoryMapEntry
         } \
     } while (0)
 
-#ifndef _ERRNO_T_DEFINED
-#define _ERRNO_T_DEFINED
-typedef int32_t errno_t;
-#endif  /* _ERRNO_T_DEFINED */
-
-extern void
-    svt_memcpy_app(void  *dst_ptr, const void  *src_ptr, size_t size);
-#ifdef ARCH_X86_64
-#define EB_MEMCPY(dst, src, size) \
-    svt_memcpy_app(dst, src, size)
-#else
-#define EB_MEMCPY(dst, src, size) \
-    memcpy(dst, src, size)
-#endif
 
 #define EB_MEMSET(dst, val, count) \
 memset(dst, val, count)
 
-//#ifdef __cplusplus
-//}
-//#endif // __cplusplus
 
 /**************************************
 * Callback Functions
@@ -2331,23 +2131,10 @@ void(*error_handler)(
 
 //***Encoding Parameters***
 
-#define INTERNAL_BIT_DEPTH                          8 // to be modified
-#define MAX_SAMPLE_VALUE                            ((1 << INTERNAL_BIT_DEPTH) - 1)
-#define MAX_SAMPLE_VALUE_10BIT                      0x3FF
-#define BLOCK_SIZE_64                                64u
-#define LOG2F_MAX_SB_SIZE                          6u
-#define LOG2_64_SIZE                                6 // log2(BLOCK_SIZE_64)
-#define MAX_LEVEL_COUNT                             5 // log2(BLOCK_SIZE_64) - log2(MIN_BLOCK_SIZE)
+#define BLOCK_SIZE_64                               64u
 #define LOG_MIN_BLOCK_SIZE                          3
 #define MIN_BLOCK_SIZE                              (1 << LOG_MIN_BLOCK_SIZE)
-#define LOG_MIN_PU_SIZE                             2
-#define MIN_PU_SIZE                                 (1 << LOG_MIN_PU_SIZE)
-#define MAX_NUM_OF_PU_PER_CU                        1
 #define MAX_NUM_OF_REF_PIC_LIST                     2
-#define MAX_NUM_OF_PART_SIZE                        8
-#define MIN_CU_BLK_COUNT                            ((BLOCK_SIZE_64 / MIN_BLOCK_SIZE) * (BLOCK_SIZE_64 / MIN_BLOCK_SIZE))
-#define MAX_NUM_OF_TU_PER_CU                        21
-#define MIN_NUM_OF_TU_PER_CU                        5
 // super-resolution definitions
 #define MIN_SUPERRES_DENOM                          8
 #define MAX_SUPERRES_DENOM                          16
@@ -2361,46 +2148,19 @@ void(*error_handler)(
 #define MAX_REF_IDX                                 4
 #define MAX_ELAPSED_IDR_COUNT                       1024
 
-typedef enum DownSamplingMethod
-{
-    ME_FILTERED_DOWNSAMPLED  = 0,
-    ME_DECIMATED_DOWNSAMPLED = 1
-} DownSamplingMethod;
-
 //***Segments***
 #define CU_MAX_COUNT                                85
 
 #define MAX_INTRA_REFERENCE_SAMPLES                 (BLOCK_SIZE_64 << 2) + 1
 
-#define _MVXT(mv) ( (int16_t)((mv) &  0xFFFF) )
-#define _MVYT(mv) ( (int16_t)((mv) >> 16    ) )
+#define _MVXT(mv)                                   ( (int16_t)((mv) &  0xFFFF) )
+#define _MVYT(mv)                                   ( (int16_t)((mv) >> 16    ) )
 
-//***MCP***
+#define MIN_QP_VALUE                                0
+#define MAX_QP_VALUE                                63
 
-#define InternalBitDepth            8                                     // to be modified
-#define MAX_Sample_Value            ((1 << InternalBitDepth) - 1)
-#define IF_Shift                    6                                     // to be modified
-#define IF_Prec                     14                                    // to be modified
-#define IF_Negative_Offset          (IF_Prec - 1)                         // to be modified
-#define InternalBitDepthIncrement   (InternalBitDepth - 8)
-
-#define MIN_QP_VALUE                     0
-#define MAX_QP_VALUE                    63
-// Noise detection
-#define  NOISE_VARIANCE_TH                390
-// Picture split into regions for analysis (SCD, Dynamic GOP)
-#define CLASS_SUB_0_REGION_SPLIT_PER_WIDTH    1
-#define CLASS_SUB_0_REGION_SPLIT_PER_HEIGHT    1
-
-#define CLASS_1_REGION_SPLIT_PER_WIDTH        2
-#define CLASS_1_REGION_SPLIT_PER_HEIGHT        2
-
-#define HIGHER_THAN_CLASS_1_REGION_SPLIT_PER_WIDTH        4
-#define HIGHER_THAN_CLASS_1_REGION_SPLIT_PER_HEIGHT        4
-#define EbScdMode uint8_t
-#define SCD_MODE_0  0     // SCD OFF
-#define SCD_MODE_1   1     // Light SCD (histograms generation on the 1/16 decimated input)
-#define SCD_MODE_2   2     // Full SCD
+#define HIGHER_THAN_CLASS_1_REGION_SPLIT_PER_WIDTH  4
+#define HIGHER_THAN_CLASS_1_REGION_SPLIT_PER_HEIGHT 4
 
 #define EbBlockMeanPrec uint8_t
 #define BLOCK_MEAN_PREC_FULL 0
@@ -2518,104 +2278,16 @@ typedef enum RasterScanCuIndex
     RASTER_SCAN_CU_INDEX_8x8_63 = 84
 } RasterScanCuIndex;
 
-static const uint32_t raster_scan_blk_x[CU_MAX_COUNT] =
-{
-    0,
-    0, 32,
-    0, 32,
-    0, 16, 32, 48,
-    0, 16, 32, 48,
-    0, 16, 32, 48,
-    0, 16, 32, 48,
-    0, 8, 16, 24, 32, 40, 48, 56,
-    0, 8, 16, 24, 32, 40, 48, 56,
-    0, 8, 16, 24, 32, 40, 48, 56,
-    0, 8, 16, 24, 32, 40, 48, 56,
-    0, 8, 16, 24, 32, 40, 48, 56,
-    0, 8, 16, 24, 32, 40, 48, 56,
-    0, 8, 16, 24, 32, 40, 48, 56,
-    0, 8, 16, 24, 32, 40, 48, 56
-};
+extern const uint32_t raster_scan_blk_x[CU_MAX_COUNT];
 
-static const uint32_t raster_scan_blk_y[CU_MAX_COUNT] =
-{
-    0,
-    0, 0,
-    32, 32,
-    0, 0, 0, 0,
-    16, 16, 16, 16,
-    32, 32, 32, 32,
-    48, 48, 48, 48,
-    0, 0, 0, 0, 0, 0, 0, 0,
-    8, 8, 8, 8, 8, 8, 8, 8,
-    16, 16, 16, 16, 16, 16, 16, 16,
-    24, 24, 24, 24, 24, 24, 24, 24,
-    32, 32, 32, 32, 32, 32, 32, 32,
-    40, 40, 40, 40, 40, 40, 40, 40,
-    48, 48, 48, 48, 48, 48, 48, 48,
-    56, 56, 56, 56, 56, 56, 56, 56
-};
+extern const uint32_t raster_scan_blk_y[CU_MAX_COUNT];
 
-static const uint32_t raster_scan_blk_size[CU_MAX_COUNT] =
-{   64,
-    32, 32,
-    32, 32,
-    16, 16, 16, 16,
-    16, 16, 16, 16,
-    16, 16, 16, 16,
-    16, 16, 16, 16,
-    8, 8, 8, 8, 8, 8, 8, 8,
-    8, 8, 8, 8, 8, 8, 8, 8,
-    8, 8, 8, 8, 8, 8, 8, 8,
-    8, 8, 8, 8, 8, 8, 8, 8,
-    8, 8, 8, 8, 8, 8, 8, 8,
-    8, 8, 8, 8, 8, 8, 8, 8,
-    8, 8, 8, 8, 8, 8, 8, 8,
-    8, 8, 8, 8, 8, 8, 8, 8
-};
+extern const uint32_t raster_scan_blk_size[CU_MAX_COUNT];
 
-static const uint32_t md_scan_to_raster_scan[CU_MAX_COUNT] =
-{
-    0,
-    1,
-    5, 21, 22, 29, 30,
-    6, 23, 24, 31, 32,
-    9, 37, 38, 45, 46,
-    10, 39, 40, 47, 48,
-    2,
-    7, 25, 26, 33, 34,
-    8, 27, 28, 35, 36,
-    11, 41, 42, 49, 50,
-    12, 43, 44, 51, 52,
-    3,
-    13, 53, 54, 61, 62,
-    14, 55, 56, 63, 64,
-    17, 69, 70, 77, 78,
-    18, 71, 72, 79, 80,
-    4,
-    15, 57, 58, 65, 66,
-    16, 59, 60, 67, 68,
-    19, 73, 74, 81, 82,
-    20, 75, 76, 83, 84
-};
+extern const uint32_t md_scan_to_raster_scan[CU_MAX_COUNT];
+
+extern const uint32_t raster_scan_blk_parent_index[CU_MAX_COUNT];
 
-static const uint32_t raster_scan_blk_parent_index[CU_MAX_COUNT] =
-{   0,
-    0, 0,
-    0, 0,
-    1, 1, 2, 2,
-    1, 1, 2, 2,
-    3, 3, 4, 4,
-    3, 3, 4, 4,
-    5, 5, 6, 6, 7, 7, 8, 8,
-    5, 5, 6, 6, 7, 7, 8, 8,
-    9, 9, 10, 10, 11, 11, 12, 12,
-    9, 9, 10, 10, 11, 11, 12, 12,
-    13, 13, 14, 14, 15, 15, 16, 16,
-    13, 13, 14, 14, 15, 15, 16, 16,
-    17, 17, 18, 18, 19, 19, 20, 20,
-    17, 17, 18, 18, 19, 19, 20, 20
-};
 typedef struct StatStruct
 {
     uint64_t   poc;
@@ -2624,27 +2296,10 @@ typedef struct StatStruct
     uint8_t    worst_qindex;
     uint8_t    temporal_layer_index;
 } StatStruct;
-#define SC_MAX_LEVEL 2 // 2 sets of HME/ME settings are used depending on the scene content mode
-static const uint8_t me_idx_85_8x8_to_16x16_conversion[] = {
-    5,5,      6,6,      7,7,      8,8,
-    5,5,      6,6,      7,7,      8,8,
 
-    9,9,      10,10,    11,11,    12,12,
-    9,9,      10,10,    11,11,    12,12,
+extern const uint8_t me_idx_85_8x8_to_16x16_conversion[64];
+extern const uint8_t me_idx_16x16_to_parent_32x32_conversion[16];
 
-    13,13,    14,14,    15,15,    16,16,
-    13,13,    14,14,    15,15,    16,16,
-
-    17,17,    18,18,    19,19,    20,20,
-    17,17,    18,18,    19,19,    20,20
-};
-static const uint8_t me_idx_16x16_to_parent_32x32_conversion[] = {
-    1,1,      2,2,
-    1,1,      2,2,
-
-    3,3,      4,4,
-    3,3,      4,4
-};
 typedef enum IntrabcMotionDirection
 {
     IBC_MOTION_ABOVE,
@@ -2663,6 +2318,9 @@ typedef enum {
 
 #define MAX_U32 0xFFFFFFFF
 
+// Both SFRAME_FLEXIBLE_BASE and SFRAME_DEC_POSI_BASE use flexible insertion
+#define IS_SFRAME_FLEXIBLE_INSERT(mode) (mode == SFRAME_FLEXIBLE_BASE || mode == SFRAME_DEC_POSI_BASE)
+
 #ifdef __cplusplus
 }
 #endif
