@@ -135,11 +135,9 @@ void *svt_aom_motion_estimation_kernel(void *input_ptr) {
             pa_ref_obj_ = (EbPaReferenceObject *)
                               pcs->pa_ref_pic_wrapper->object_ptr;
             // Set 1/4 and 1/16 ME input buffer(s); filtered or decimated
-            quarter_picture_ptr = (EbPictureBufferDesc *)
-                                      pa_ref_obj_->quarter_downsampled_picture_ptr;
-            sixteenth_picture_ptr = (EbPictureBufferDesc *)
-                                        pa_ref_obj_->sixteenth_downsampled_picture_ptr;
-            input_padded_pic = (EbPictureBufferDesc *)pa_ref_obj_->input_padded_pic;
+            quarter_picture_ptr = pa_ref_obj_->quarter_downsampled_picture_ptr;
+            sixteenth_picture_ptr = pa_ref_obj_->sixteenth_downsampled_picture_ptr;
+            input_padded_pic = pa_ref_obj_->input_padded_pic;
 
             input_pic = pcs->enhanced_pic;
 
@@ -286,13 +284,6 @@ void *svt_aom_motion_estimation_kernel(void *input_ptr) {
                         }
                     }
                 }
-
-                if (scs->in_loop_ois == 0 && pcs->tpl_ctrls.enable)
-                    for (uint32_t y_b64_index = y_b64_start_index; y_b64_index < y_b64_end_index; ++y_b64_index)
-                        for (uint32_t x_b64_index = x_b64_start_index; x_b64_index < x_b64_end_index; ++x_b64_index) {
-                            uint32_t b64_index = (uint16_t)(x_b64_index + y_b64_index * pic_width_in_b64);
-                            svt_aom_open_loop_intra_search_mb(pcs, b64_index, input_pic);
-                        }
             }
             // Get Empty Results Object
             svt_get_empty_object(me_context_ptr->motion_estimation_results_output_fifo_ptr,
