@@ -29,7 +29,7 @@
 #include <vector>
 #include "EbSvtAv1Enc.h"
 #include "gtest/gtest.h"
-#include "EbDefinitions.h"
+#include "definitions.h"
 
 using std::vector;
 
@@ -131,11 +131,14 @@ static const vector<uint32_t> default_hierarchical_levels = {
 };
 static const vector<uint32_t> valid_hierarchical_levels = {3, 4, 5};
 static const vector<uint32_t> invalid_hierarchical_levels = {
-    0, 1, 2, 6,  // ...
+    0,
+    1,
+    2,
+    6,  // ...
 };
 
 /* Prediction structure used to construct GOP. There are two main structures
- * supported, which are: Low Delay (P or b) and Random Access.
+ * supported, which are: Low Delay and Random Access.
  *
  * In Low Delay structure, pictures within a mini GOP refer to the previously
  * encoded pictures in display order. In other words, pictures with display
@@ -146,23 +149,18 @@ static const vector<uint32_t> invalid_hierarchical_levels = {
  * reference picture list 0 and the reference picture list 1 will contain the
  * same reference picture.
  *
- * Following values are supported and defined in EbDefinitions.h
- * #define SVT_AV1_PRED_LOW_DELAY_P     0
- * #define SVT_AV1_PRED_LOW_DELAY_B     1
- * #define SVT_AV1_PRED_RANDOM_ACCESS   2
- * #define SVT_AV1_PRED_TOTAL_COUNT     3
+ * Following values are supported and defined in definitions.h
+ * #define LOW_DELAY       1
+ * #define RANDOM_ACCESS   2
 
  * In Random Access structure, the b/b pictures can refer to reference pictures
  * from both directions (past and future).
  *
  * Default is 2. */
 static const vector<uint8_t> default_pred_structure = {
-    SVT_AV1_PRED_RANDOM_ACCESS,
+    RANDOM_ACCESS,
 };
-static const vector<uint8_t> valid_pred_structure = {
-    SVT_AV1_PRED_LOW_DELAY_P,
-    SVT_AV1_PRED_LOW_DELAY_B,
-    SVT_AV1_PRED_RANDOM_ACCESS};
+static const vector<uint8_t> valid_pred_structure = {LOW_DELAY, RANDOM_ACCESS};
 static const vector<uint8_t> invalid_pred_structure = {
     /* _pred_structure override in code
     SVT_AV1_PRED_TOTAL_COUNT, SVT_AV1_PRED_TOTAL_COUNT + 1, EB_PRED_INVALID*/};
@@ -175,10 +173,27 @@ static const vector<uint32_t> default_source_width = {
     0,
 };
 static const vector<uint32_t> valid_source_width = {
-    64, 320, 640, 800, 1280, 1920, 2560, 3840, 4096,  // ...
+    64,
+    320,
+    640,
+    800,
+    1280,
+    1920,
+    2560,
+    3840,
+    4096,  // ...
 };
 static const vector<uint32_t> invalid_source_width = {
-    0, 1, 2, 4, 8, 16, 32, 63, 65, 4097,  // ...
+    0,
+    1,
+    2,
+    4,
+    8,
+    16,
+    32,
+    63,
+    65,
+    4097,  // ...
 };
 
 /* The height of input source in units of picture luma pixels.
@@ -188,10 +203,26 @@ static const vector<uint32_t> default_source_height = {
     0,
 };
 static const vector<uint32_t> valid_source_height = {
-    64, 240, 480, 720, 1080, 1440, 1600, 2160,  // ...
+    64,
+    240,
+    480,
+    720,
+    1080,
+    1440,
+    1600,
+    2160,  // ...
 };
 static const vector<uint32_t> invalid_source_height = {
-    0, 1, 2, 4, 8, 16, 32, 63, 65, 2161,  // ...
+    0,
+    1,
+    2,
+    4,
+    8,
+    16,
+    32,
+    63,
+    65,
+    2161,  // ...
 };
 
 // TODO: follwoing two parameters should be a combination test
@@ -265,7 +296,10 @@ static const vector<uint32_t> valid_encoder_bit_depth = {
     10,  // 10 bit.
 };
 static const vector<uint32_t> invalid_encoder_bit_depth = {
-    0, 1, 2, 11,  // ...
+    0,
+    1,
+    2,
+    11,  // ...
 };
 
 /* Offline packing of the 2bits: requires two bits packed input.
@@ -279,7 +313,8 @@ static const vector<uint32_t> valid_compressed_ten_bit_format = {
     // 1, Not supported in this version
 };
 static const vector<uint32_t> invalid_compressed_ten_bit_format = {
-    2, 10,  // ...
+    2,
+    10,  // ...
 };
 
 /* Number of frames of sequence to be encoded. If number of frames is greater
@@ -293,7 +328,12 @@ static const vector<uint64_t> default_frames_to_be_encoded = {
     0,
 };
 static const vector<uint64_t> valid_frames_to_be_encoded = {
-    0, 1, 10, 100, 10000, (uint64_t)0xFFFFFFFFFFFFFFFF,  // ...
+    0,
+    1,
+    10,
+    100,
+    10000,
+    (uint64_t)0xFFFFFFFFFFFFFFFF,  // ...
 };
 static const vector<uint64_t> invalid_frames_to_be_encoded = {
     // none
@@ -366,14 +406,14 @@ static const vector<uint32_t> invalid_qp = {
 /* force qp values for every picture that are passed in the header pointer
  *
  * Default is 0.*/
-static const vector<Bool> default_use_qp_file = {
-    FALSE,
+static const vector<bool> default_use_qp_file = {
+    false,
 };
-static const vector<Bool> valid_use_qp_file = {
-    FALSE,
-    TRUE,
+static const vector<bool> valid_use_qp_file = {
+    false,
+    true,
 };
-static const vector<Bool> invalid_use_qp_file = {
+static const vector<bool> invalid_use_qp_file = {
     // none
 };
 
@@ -381,29 +421,28 @@ static const vector<Bool> invalid_use_qp_file = {
 /* Flag to enable the Deblocking Loop Filtering.
  *
  * Default is true. */
-static const vector<Bool> default_enable_dlf_flag = {
-    TRUE,
+static const vector<uint8_t> default_enable_dlf_flag = {
+    1,
 };
-static const vector<Bool> valid_enable_dlf_flag = {
-    FALSE,
-    TRUE,
-};
-static const vector<Bool> invalid_enable_dlf_flag = {
-    // none
+static const vector<uint8_t> valid_enable_dlf_flag = {
+    0,
+    1,
+    2,
 };
+static const vector<uint8_t> invalid_enable_dlf_flag = {3};
 
 /* Film grain denoising the input picture
  * Flag to enable the denoising
  *
  * Default is 0. */
 // TODO: the description of this parameter is incorrect, refer to source code,
-// it should be a Bool
+// it should be a bool
 static const vector<uint32_t> default_film_grain_denoise_strength = {
-    FALSE,
+    false,
 };
 static const vector<uint32_t> valid_film_grain_denoise_strength = {
-    FALSE,
-    TRUE,
+    false,
+    true,
 };
 static const vector<uint32_t> invalid_film_grain_denoise_strength = {
     // none
@@ -412,70 +451,70 @@ static const vector<uint32_t> invalid_film_grain_denoise_strength = {
 /* Warped motion
  *
  * Default is 0. */
-static const vector<Bool> default_enable_warped_motion = {
-    TRUE,
+static const vector<bool> default_enable_warped_motion = {
+    true,
 };
-static const vector<Bool> valid_enable_warped_motion = {
-    FALSE,
-    TRUE,
+static const vector<bool> valid_enable_warped_motion = {
+    false,
+    true,
 };
-static const vector<Bool> invalid_enable_warped_motion = {
+static const vector<bool> invalid_enable_warped_motion = {
     // none
 };
 
 /* Global motion
  *
  * Default is 1. */
-static const vector<Bool> default_enable_global_motion = {
-    TRUE,
+static const vector<bool> default_enable_global_motion = {
+    true,
 };
-static const vector<Bool> valid_enable_global_motion = {
-    FALSE,
-    TRUE,
+static const vector<bool> valid_enable_global_motion = {
+    false,
+    true,
 };
-static const vector<Bool> invalid_enable_global_motion = {
+static const vector<bool> invalid_enable_global_motion = {
     // none
 };
 
 /* Flag to enable the use of default ME HME parameters.
  *
  * Default is 1. */
-static const vector<Bool> default_use_default_me_hme = {
-    TRUE,
+static const vector<bool> default_use_default_me_hme = {
+    true,
 };
-static const vector<Bool> valid_use_default_me_hme = {
-    FALSE,
-    TRUE,
+static const vector<bool> valid_use_default_me_hme = {
+    false,
+    true,
 };
-static const vector<Bool> invalid_use_default_me_hme = {
+static const vector<bool> invalid_use_default_me_hme = {
     // none
 };
 
 /* Flag to enable Hierarchical Motion Estimation.
  *
  * Default is 1. */
-static const vector<Bool> default_enable_hme_flag = {
-    TRUE,
+static const vector<bool> default_enable_hme_flag = {
+    true,
 };
-static const vector<Bool> valid_enable_hme_flag = {
-    FALSE,
-    TRUE,
+static const vector<bool> valid_enable_hme_flag = {
+    false,
+    true,
 };
-static const vector<Bool> invalid_enable_hme_flag = {
+static const vector<bool> invalid_enable_hme_flag = {
     // none
 };
 
 /* Flag to enable the use of non-swaure partitions
  *
  * Default is 0. */
-static const vector<Bool> default_ext_block_flag = {
-    FALSE,
+static const vector<bool> default_ext_block_flag = {
+    false,
 };
-static const vector<Bool> valid_ext_block_flag = {
-    FALSE,
-    TRUE,
+static const vector<bool> valid_ext_block_flag = {
+    false,
+    true,
 };
-static const vector<Bool> invalid_ext_block_flag = {
+static const vector<bool> invalid_ext_block_flag = {
     // none
 };
 
@@ -487,10 +526,22 @@ static const vector<uint32_t> default_search_area_width = {
     16,  // 0,
 };
 static const vector<uint32_t> valid_search_area_width = {
-    1, 2, 3, 4, 8, 10, 16, 32, 64, 128, 256,  // ...
+    1,
+    2,
+    3,
+    4,
+    8,
+    10,
+    16,
+    32,
+    64,
+    128,
+    256,  // ...
 };
 static const vector<uint32_t> invalid_search_area_width = {
-    0, 257, 1000,  // ...
+    0,
+    257,
+    1000,  // ...
 };
 
 /* Number of search positions in the vertical direction.
@@ -500,10 +551,22 @@ static const vector<uint32_t> default_search_area_height = {
     7,  // 0,
 };
 static const vector<uint32_t> valid_search_area_height = {
-    1, 2, 3, 4, 8, 10, 16, 32, 64, 128, 256,  // ...
+    1,
+    2,
+    3,
+    4,
+    8,
+    10,
+    16,
+    32,
+    64,
+    128,
+    256,  // ...
 };
 static const vector<uint32_t> invalid_search_area_height = {
-    0, 257, 1000,  // ...
+    0,
+    257,
+    1000,  // ...
 };
 
 // MD Parameters
@@ -526,14 +589,14 @@ static const vector<int32_t> invalid_palette_level = {-2, 7};
  * parameter sets in the elementary streams .
  *
  * Default is 0. */
-static const vector<Bool> default_constrained_intra = {
-    FALSE,
+static const vector<bool> default_constrained_intra = {
+    false,
 };
-static const vector<Bool> valid_constrained_intra = {
-    FALSE,
-    TRUE,
+static const vector<bool> valid_constrained_intra = {
+    false,
+    true,
 };
-static const vector<Bool> invalid_constrained_intra = {
+static const vector<bool> invalid_constrained_intra = {
     // none
 };
 
@@ -544,10 +607,9 @@ static const vector<Bool> invalid_constrained_intra = {
  * 1 = Average BitRate.
  *
  * Default is 0. */
-static const vector<uint32_t> default_rate_control_mode = {0};
-static const vector<uint32_t> valid_rate_control_mode = {0, 1, 2};
-static const vector<uint32_t> invalid_rate_control_mode = {3, 4};
-
+static const vector<uint8_t> default_rate_control_mode = {0};
+static const vector<uint8_t> valid_rate_control_mode = {0, 1, 2};
+static const vector<uint8_t> invalid_rate_control_mode = {3, 4};
 /* Flag to enable the scene change detection algorithm.
  *
  * Default is 0. */
@@ -707,14 +769,15 @@ static const vector<uint32_t> invalid_level = {
 
 /* Assembly instruction set used by encoder.
  *
- * 0 = non-AVX2, C only.
- * 1 = up to AVX512, auto-select highest assembly instruction set supported.
+ * 0 = non-SIMD, C only.
+ * EB_CPU_FLAGS_ALL = auto-select highest assembly instruction set supported.
  *
- * Default is 1. */
+ * Default is EB_CPU_FLAGS_ALL. */
 static const vector<EbCpuFlags> default_use_cpu_flags = {
     EB_CPU_FLAGS_ALL,
 };
 static const vector<EbCpuFlags> valid_use_cpu_flags = {
+#ifdef ARCH_X86_64
     EB_CPU_FLAGS_MMX,
     EB_CPU_FLAGS_SSE,
     EB_CPU_FLAGS_SSE2,
@@ -727,57 +790,20 @@ static const vector<EbCpuFlags> valid_use_cpu_flags = {
     EB_CPU_FLAGS_AVX512F,
     EB_CPU_FLAGS_AVX512CD,
     EB_CPU_FLAGS_AVX512DQ,
-    EB_CPU_FLAGS_AVX512ER,
-    EB_CPU_FLAGS_AVX512PF,
     EB_CPU_FLAGS_AVX512BW,
     EB_CPU_FLAGS_AVX512VL,
+    EB_CPU_FLAGS_AVX512ICL,
+#elif defined(ARCH_AARCH64)
+    EB_CPU_FLAGS_NEON,
+    EB_CPU_FLAGS_ARM_CRC32,
+    EB_CPU_FLAGS_NEON_DOTPROD,
+    EB_CPU_FLAGS_NEON_I8MM,
+    EB_CPU_FLAGS_SVE,
+    EB_CPU_FLAGS_SVE2,
+#endif
 };
 static const vector<EbCpuFlags> invalid_use_cpu_flags = {EB_CPU_FLAGS_INVALID};
 
-// Application Specific parameters
-/**
- * @brief API signal for the library to know the channel ID (used for pinning to
- * cores)
- *
- */
-static const vector<uint32_t> default_channel_id = {
-    0,
-};
-static const vector<uint32_t> valid_channel_id = {
-    0,
-    1,
-    2,
-    3,
-    10,
-    100,
-    0xFFFFFFFF,
-};
-static const vector<uint32_t> invalid_channel_id = {
-    // none
-};
-
-/**
- * @brief API signal for the library to know the active number of channels being
- * encoded simultaneously
- *
- */
-static const vector<uint32_t> default_active_channel_count = {
-    1,
-};
-static const vector<uint32_t> valid_active_channel_count = {
-    1,
-    2,
-    3,
-    10,
-    100,
-    0xFFFFFFFF,
-};
-static const vector<uint32_t> invalid_active_channel_count = {
-    /* active_channel_count override in code
-    0,
-    */
-};
-
 /* Flag to enable the Speed Control functionality to achieve the real-time
  * encoding speed defined by dynamically changing the encoding preset to meet
  * the average speed defined in injectorFrameRate. When this parameter is set
@@ -797,13 +823,12 @@ static const vector<uint32_t> invalid_speed_control_flag = {
 
 // Threads management
 
-/* The number of logical processor which encoder threads run on. If
- * LogicalProcessors and TargetSocket are not set, threads are managed by
- * OS thread scheduler. */
-static const vector<uint32_t> default_logical_processors = {
+/* The level of parallelism the encoder employs (how many threads and pictures
+ * to create). */
+static const vector<uint32_t> default_level_of_parallelism = {
     0,
 };
-static const vector<uint32_t> valid_logical_processors = {
+static const vector<uint32_t> valid_level_of_parallelism = {
     0,
     1,
     2,
@@ -820,38 +845,18 @@ static const vector<uint32_t> valid_logical_processors = {
     1000,
     0xFFFFFFFF,
 };
-static const vector<uint32_t> invalid_logical_processors = {
+static const vector<uint32_t> invalid_level_of_parallelism = {
     // ...
 };
 
-/* Target socket to run on. For dual socket systems, this can specify which
- * socket the encoder runs on.
- *
- * -1 = Both Sockets.
- *  0 = Socket 0.
- *  1 = Socket 1.
- *
- * Default is -1. */
-static const vector<int32_t> default_target_socket = {
-    -1,
-};
-static const vector<int32_t> valid_target_socket = {
-    -1,
-    0,
-    1,
-};
-static const vector<int32_t> invalid_target_socket = {
-    2,
-};
-
 // Debug tools
 
 /* Output reconstructed yuv used for debug purposes. The value is set through
  * ReconFile token (-o) and using the feature will affect the speed of encoder.
  *
  * Default is 0. */
-static const vector<uint32_t> default_recon_enabled = {FALSE};
-static const vector<uint32_t> valid_recon_enabled = {FALSE, TRUE};
+static const vector<uint32_t> default_recon_enabled = {false};
+static const vector<uint32_t> valid_recon_enabled = {false, true};
 static const vector<uint32_t> invalid_recon_enabled = {/** none */};
 
 #if TILES
@@ -896,14 +901,14 @@ static const vector<int32_t> invalid_tile_rows = {
  *
  * Default is 2. */
 static const vector<uint32_t> default_screen_content_mode = {2};
-static const vector<uint32_t> valid_screen_content_mode = {0, 1, 2};
-static const vector<uint32_t> invalid_screen_content_mode = {3};
+static const vector<uint32_t> valid_screen_content_mode = {0, 1, 2, 3};
+static const vector<uint32_t> invalid_screen_content_mode = {4};
 
 /* Variables to control the use of ALT-REF (temporally filtered frames)
  */
-static const vector<Bool> default_enable_tf = {TRUE};
-static const vector<Bool> valid_enable_tf = {FALSE, TRUE};
-static const vector<Bool> invalid_enable_tf = {/*none*/};
+static const vector<uint8_t> default_enable_tf = {1};
+static const vector<uint8_t> valid_enable_tf = {0, 1, 2};
+static const vector<uint8_t> invalid_enable_tf = {3};
 
 static const vector<uint8_t> default_altref_strength = {5};
 static const vector<uint8_t> valid_altref_strength = {0, 1, 2, 3, 4, 5, 6};
@@ -914,9 +919,9 @@ static const vector<uint8_t> valid_altref_nframes = {
     0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10};
 static const vector<uint8_t> invalid_altref_nframes = {11};
 
-static const vector<Bool> default_enable_overlays = {FALSE};
-static const vector<Bool> valid_enable_overlays = {FALSE, TRUE};
-static const vector<Bool> invalid_enable_overlays = {/*none*/};
+static const vector<bool> default_enable_overlays = {false};
+static const vector<bool> valid_enable_overlays = {false, true};
+static const vector<bool> invalid_enable_overlays = {/*none*/};
 
 /* Variables to control the super-resolution tool
  */
