@@ -91,8 +91,8 @@ using highbd_convolve_func =
 
 using lowbd_convolve_func = void (*)(const uint8_t *src, int src_stride,
                                      uint8_t *dst, int dst_stride, int w, int h,
-                                     InterpFilterParams *filter_params_x,
-                                     InterpFilterParams *filter_params_y,
+                                     const InterpFilterParams *filter_params_x,
+                                     const InterpFilterParams *filter_params_y,
                                      const int subpel_x_qn,
                                      const int subpel_y_qn,
                                      ConvolveParams *conv_params);
@@ -131,13 +131,12 @@ class AV1ConvolveTest : public ::testing::TestWithParam<ConvolveParam> {
         svt_aom_free(output_init_);
         svt_aom_free(output_ref_);
         svt_aom_free(output_tst_);
-        aom_clear_system_state();
     }
 
     virtual void run_convolve(int offset_r, int offset_c, int src_stride,
                               int dst_stride, int w, int h,
-                              InterpFilterParams *filter_params_x,
-                              InterpFilterParams *filter_params_y,
+                              const InterpFilterParams *filter_params_x,
+                              const InterpFilterParams *filter_params_y,
                               const int32_t subpel_x_q4,
                               const int32_t subpel_y_q4,
                               ConvolveParams *conv_params1,
@@ -145,8 +144,8 @@ class AV1ConvolveTest : public ::testing::TestWithParam<ConvolveParam> {
 
     virtual void speed_convolve(int offset_r, int offset_c, int src_stride,
                                 int dst_stride, int w, int h,
-                                InterpFilterParams *filter_params_x,
-                                InterpFilterParams *filter_params_y,
+                                const InterpFilterParams *filter_params_x,
+                                const InterpFilterParams *filter_params_y,
                                 const int32_t subpel_x_q4,
                                 const int32_t subpel_y_q4,
                                 ConvolveParams *conv_params1,
@@ -154,8 +153,8 @@ class AV1ConvolveTest : public ::testing::TestWithParam<ConvolveParam> {
 
     void test_convolve(int has_subx, int has_suby, int src_stride,
                        int dst_stride, int output_w, int output_h,
-                       InterpFilterParams *filter_params_x,
-                       InterpFilterParams *filter_params_y,
+                       const InterpFilterParams *filter_params_x,
+                       const InterpFilterParams *filter_params_y,
                        ConvolveParams *conv_params_ref,
                        ConvolveParams *conv_params_tst) {
         const int subx_range = has_subx ? 16 : 1;
@@ -240,8 +239,8 @@ class AV1ConvolveTest : public ::testing::TestWithParam<ConvolveParam> {
 
     void test_speed(int has_subx, int has_suby, int src_stride, int dst_stride,
                     int output_w, int output_h,
-                    InterpFilterParams *filter_params_x,
-                    InterpFilterParams *filter_params_y,
+                    const InterpFilterParams *filter_params_x,
+                    const InterpFilterParams *filter_params_y,
                     ConvolveParams *conv_params_ref,
                     ConvolveParams *conv_params_tst) {
         const int subx_range = has_subx ? 16 : 1;
@@ -571,8 +570,8 @@ class AV1LbdConvolveTest
     }
     void run_convolve(int offset_r, int offset_c, int src_stride,
                       int dst_stride, int output_w, int output_h,
-                      InterpFilterParams *filter_params_x,
-                      InterpFilterParams *filter_params_y,
+                      const InterpFilterParams *filter_params_x,
+                      const InterpFilterParams *filter_params_y,
                       const int32_t subpel_x_q4, const int32_t subpel_y_q4,
                       ConvolveParams *conv_params_ref,
                       ConvolveParams *conv_params_tst) override {
@@ -602,8 +601,8 @@ class AV1LbdConvolveTest
 
     void speed_convolve(int offset_r, int offset_c, int src_stride,
                         int dst_stride, int output_w, int output_h,
-                        InterpFilterParams *filter_params_x,
-                        InterpFilterParams *filter_params_y,
+                        const InterpFilterParams *filter_params_x,
+                        const InterpFilterParams *filter_params_y,
                         const int32_t subpel_x_q4, const int32_t subpel_y_q4,
                         ConvolveParams *conv_params_ref,
                         ConvolveParams *conv_params_tst) override {
@@ -735,6 +734,30 @@ INSTANTIATE_TEST_SUITE_P(ConvolveTestY_NEON, AV1LbdJntConvolveTest,
 INSTANTIATE_TEST_SUITE_P(ConvolveTestCOPY_NEON, AV1LbdJntConvolveTest,
                          BuildParamsLbd(0, 0,
                                         svt_av1_jnt_convolve_2d_copy_neon));
+
+#if HAVE_NEON_DOTPROD
+INSTANTIATE_TEST_SUITE_P(ConvolveTest2D_NEON_DOTPROD, AV1LbdJntConvolveTest,
+                         BuildParamsLbd(1, 1,
+                                        svt_av1_jnt_convolve_2d_neon_dotprod));
+INSTANTIATE_TEST_SUITE_P(ConvolveTestX_NEON_DOTPROD, AV1LbdJntConvolveTest,
+                         BuildParamsLbd(1, 0,
+                                        svt_av1_jnt_convolve_x_neon_dotprod));
+INSTANTIATE_TEST_SUITE_P(ConvolveTestY_NEON_DOTPROD, AV1LbdJntConvolveTest,
+                         BuildParamsLbd(0, 1,
+                                        svt_av1_jnt_convolve_y_neon_dotprod));
+#endif  // HAVE_DOTPROD
+
+#if HAVE_NEON_I8MM
+INSTANTIATE_TEST_SUITE_P(ConvolveTest2D_NEON_I8MM, AV1LbdJntConvolveTest,
+                         BuildParamsLbd(1, 1,
+                                        svt_av1_jnt_convolve_2d_neon_i8mm));
+INSTANTIATE_TEST_SUITE_P(ConvolveTestX_NEON_I8MM, AV1LbdJntConvolveTest,
+                         BuildParamsLbd(1, 0,
+                                        svt_av1_jnt_convolve_x_neon_i8mm));
+INSTANTIATE_TEST_SUITE_P(ConvolveTestY_NEON_I8MM, AV1LbdJntConvolveTest,
+                         BuildParamsLbd(0, 1,
+                                        svt_av1_jnt_convolve_y_neon_i8mm));
+#endif  // HAVE_NEON_I8MM
 #endif  // ARCH_AARCH64
 
 class AV1LbdSrConvolveTest : public AV1LbdConvolveTest {
@@ -806,11 +829,33 @@ INSTANTIATE_TEST_SUITE_P(ConvolveTestY_NEON, AV1LbdSrConvolveTest,
 INSTANTIATE_TEST_SUITE_P(ConvolveTestCOPY_NEON, AV1LbdSrConvolveTest,
                          BuildParamsLbd(0, 0,
                                         svt_av1_convolve_2d_copy_sr_neon));
+
+#if HAVE_NEON_DOTPROD
+INSTANTIATE_TEST_SUITE_P(ConvolveTest2D_NEON_DOTPROD, AV1LbdSrConvolveTest,
+                         BuildParamsLbd(1, 1,
+                                        svt_av1_convolve_2d_sr_neon_dotprod));
+INSTANTIATE_TEST_SUITE_P(ConvolveTestX_NEON_DOTPROD, AV1LbdSrConvolveTest,
+                         BuildParamsLbd(1, 0,
+                                        svt_av1_convolve_x_sr_neon_dotprod));
+INSTANTIATE_TEST_SUITE_P(ConvolveTestY_NEON_DOTPROD, AV1LbdSrConvolveTest,
+                         BuildParamsLbd(0, 1,
+                                        svt_av1_convolve_y_sr_neon_dotprod));
+#endif  // HAVE_NEON_DOTPROD
+
+#if HAVE_NEON_I8MM
+INSTANTIATE_TEST_SUITE_P(ConvolveTest2D_NEON_I8MM, AV1LbdSrConvolveTest,
+                         BuildParamsLbd(1, 1,
+                                        svt_av1_convolve_2d_sr_neon_i8mm));
+INSTANTIATE_TEST_SUITE_P(ConvolveTestX_NEON_I8MM, AV1LbdSrConvolveTest,
+                         BuildParamsLbd(1, 0, svt_av1_convolve_x_sr_neon_i8mm));
+INSTANTIATE_TEST_SUITE_P(ConvolveTestY_NEON_I8MM, AV1LbdSrConvolveTest,
+                         BuildParamsLbd(0, 1, svt_av1_convolve_y_sr_neon_i8mm));
+#endif  // HAVE_NEON_I8MM
 #endif  // ARCH_AARCH64
 
 ::testing::internal::ParamGenerator<HighbdConvolveParam> BuildParamsHbd(
     int has_subx, int has_suby, highbd_convolve_func func) {
-    return ::testing::Combine(::testing::Range(8, 13, 2),
+    return ::testing::Combine(::testing::Range(8, 11, 2),
                               ::testing::Values(has_subx),
                               ::testing::Values(has_suby),
                               ::testing::Values(func),
@@ -827,8 +872,8 @@ class AV1HbdConvolveTest
     }
     void run_convolve(int offset_r, int offset_c, int src_stride,
                       int dst_stride, int blk_w, int blk_h,
-                      InterpFilterParams *filter_params_x,
-                      InterpFilterParams *filter_params_y,
+                      const InterpFilterParams *filter_params_x,
+                      const InterpFilterParams *filter_params_y,
                       const int32_t subpel_x_q4, const int32_t subpel_y_q4,
                       ConvolveParams *conv_params_ref,
                       ConvolveParams *conv_params_tst) override {
@@ -860,8 +905,8 @@ class AV1HbdConvolveTest
 
     void speed_convolve(int offset_r, int offset_c, int src_stride,
                         int dst_stride, int output_w, int output_h,
-                        InterpFilterParams *filter_params_x,
-                        InterpFilterParams *filter_params_y,
+                        const InterpFilterParams *filter_params_x,
+                        const InterpFilterParams *filter_params_y,
                         const int32_t subpel_x_q4, const int32_t subpel_y_q4,
                         ConvolveParams *conv_params_ref,
                         ConvolveParams *conv_params_tst) override {
@@ -986,11 +1031,24 @@ INSTANTIATE_TEST_SUITE_P(ConvolveTestX_NEON, AV1HbdJntConvolveTest,
 INSTANTIATE_TEST_SUITE_P(ConvolveTestY_NEON, AV1HbdJntConvolveTest,
                          BuildParamsHbd(0, 1,
                                         svt_av1_highbd_jnt_convolve_y_neon));
-// not yet ported
-// INSTANTIATE_TEST_SUITE_P(ConvolveTestCOPY_NEON, AV1HbdJntConvolveTest,
-//                         BuildParamsHbd(0, 0,
-//                         svt_av1_highbd_jnt_convolve_2d_copy_neon));
+INSTANTIATE_TEST_SUITE_P(
+    ConvolveTestCOPY_NEON, AV1HbdJntConvolveTest,
+    BuildParamsHbd(0, 0, svt_av1_highbd_jnt_convolve_2d_copy_neon));
 
+#if HAVE_SVE
+INSTANTIATE_TEST_SUITE_P(ConvolveTestX_SVE, AV1HbdJntConvolveTest,
+                         BuildParamsHbd(1, 0,
+                                        svt_av1_highbd_jnt_convolve_x_sve));
+#endif  // HAVE_SVE
+
+#if HAVE_SVE2
+INSTANTIATE_TEST_SUITE_P(ConvolveTest2D_SVE2, AV1HbdJntConvolveTest,
+                         BuildParamsHbd(1, 1,
+                                        svt_av1_highbd_jnt_convolve_2d_sve2));
+INSTANTIATE_TEST_SUITE_P(ConvolveTestY_SVE2, AV1HbdJntConvolveTest,
+                         BuildParamsHbd(0, 1,
+                                        svt_av1_highbd_jnt_convolve_y_sve2));
+#endif  // HAVE_SVE2
 #endif  // ARCH_AARCH64
 
 class AV1HbdSrConvolveTest : public AV1HbdConvolveTest {
@@ -1051,18 +1109,30 @@ INSTANTIATE_TEST_SUITE_P(
 INSTANTIATE_TEST_SUITE_P(ConvolveTest2D_NEON, AV1HbdSrConvolveTest,
                          BuildParamsHbd(1, 1,
                                         svt_av1_highbd_convolve_2d_sr_neon));
-// Not yet implemented
-// INSTANTIATE_TEST_SUITE_P(ConvolveTestX_NEON, AV1HbdSrConvolveTest,
-//                         BuildParamsHbd(1, 0,
-//                         svt_av1_highbd_convolve_x_sr_neon));
+INSTANTIATE_TEST_SUITE_P(ConvolveTestX_NEON, AV1HbdSrConvolveTest,
+                         BuildParamsHbd(1, 0,
+                                        svt_av1_highbd_convolve_x_sr_neon));
 INSTANTIATE_TEST_SUITE_P(ConvolveTestY_NEON, AV1HbdSrConvolveTest,
                          BuildParamsHbd(0, 1,
                                         svt_av1_highbd_convolve_y_sr_neon));
-// Not yet implemented
-// INSTANTIATE_TEST_SUITE_P(ConvolveTestCOPY_NEON, AV1HbdSrConvolveTest,
-//                         BuildParamsHbd(0, 0,
-//                         svt_av1_highbd_convolve_2d_copy_sr_neon));
+INSTANTIATE_TEST_SUITE_P(
+    ConvolveTestCOPY_NEON, AV1HbdSrConvolveTest,
+    BuildParamsHbd(0, 0, svt_av1_highbd_convolve_2d_copy_sr_neon));
 
+#if HAVE_SVE
+INSTANTIATE_TEST_SUITE_P(ConvolveTestX_SVE, AV1HbdSrConvolveTest,
+                         BuildParamsHbd(1, 0,
+                                        svt_av1_highbd_convolve_x_sr_sve));
+#endif  // HAVE_SVE
+
+#if HAVE_SVE2
+INSTANTIATE_TEST_SUITE_P(ConvolveTest2D_SVE2, AV1HbdSrConvolveTest,
+                         BuildParamsHbd(1, 1,
+                                        svt_av1_highbd_convolve_2d_sr_sve2));
+INSTANTIATE_TEST_SUITE_P(ConvolveTestY_SVE2, AV1HbdSrConvolveTest,
+                         BuildParamsHbd(0, 1,
+                                        svt_av1_highbd_convolve_y_sr_sve2));
+#endif  // HAVE_SVE2
 #endif  // ARCH_AARCH64
 
 }  // namespace
